'------------------------------------------------
'1. Title Block
'     Author: Alexis Kyriacou
'     Date:29apr11
'     File Name: remote control code
'------------------------------------------------
'2. Program Description:
'------------------------------------------------
'3. Compiler Directives (these tell Bascom things about our hardware)

$crystal = 8000000                                          'speed of internal oscilator
$regfile = "m328pdef.dat"                                   'C which programmed
$hwstack = 32
$swstack = 30
$framesize = 34

'------------------------------------------------
'4. Hardware Setup direction of all ports

Config Portb = Output
Config Portd.3 = Output
Config Portd.4 = Output
Config Portd.5 = Output
Config Portd.6 = Output
Config Portd.6 = Output

Config Lcdpin = Pin , Db4 = Portb.2 , Db5 = Portb.3 , Db6 = Portb.4 , Db7 = Portb.5 , E = Portb.1 , Rs = Portb.0       'assing lcd pin with C port
Config Lcd = 16x2                                           'what type of lcd was used

'------------------------------------------------
'5. Hardware aliases
'------------------------------------------------
'6. Initialise port so hardware starts correctly
Config Date = Dmy , Separator = /
Config Rc5 = Pind.2 , Wait = 2000
Config Timer1 = Timer , Prescale = 1                        'the interrupt routine is inserted automatic but we need to make it occur
Enable Interrupts                                           'so enable the interrupts
Config Clock = Soft

Cls                                                         'clears LCD display
Cursor Off
'------------------------------------------------
'7. Declare variables

Date$ = "09/09/11"
Time$ = "15:19:00"

Declare Sub Poweronoff
Declare Sub Poweron
Declare Sub Poweroff
Declare Sub Vol_up
Declare Sub Vol_dw
Declare Sub Mute
Declare Sub Menu
Declare Sub Tv
Declare Sub Cd_dvd
Declare Sub In_one
Declare Sub In_two
Declare Sub Datetime


Dim Address As Byte , Command As Byte
Dim Position As Byte
Dim Volume As Integer , Pwr As Bit
Pwr = 0

'------------------------------------------------
'8. Initialise variables
'------------------------------------------------
'9. Declare constants
Const Timedelay = 500
'------------------------------------------------
'10. Program starts here
Volume = 0
Do

 If Pwr = 0 Then
    Getrc5(address , Command)                               'we check for the remote control address and that is 0
    If Address = 0 Then
      Command = Command And &B01111111                      'clear the toggle bit the toggle bit toggles on each new received command toggle bit is bit 7.
    End If                                                  ' Extended RC5 bit is in bit 6
  Select Case Command
    Case 12 : Call Poweronoff
  End Select
 End If


 If Pwr = 1 Then
    Getrc5(address , Command)
    If Address = 0 Then
    Command = Command And &B01111111
    End If

  Select Case Command
  Case 16 : Call Vol_up
  Case 17 : Call Vol_dw
  Case 13 : Call Mute
  Case 12 : Call Poweronoff
  Case 62 : Call Menu
  End Select

  Call Datetime
 End If

Loop
End                                                         'end program
'------------------------------------------------
'11. Subroutines
'-------volume up-------------
Sub Vol_up :
If Volume < 20 Then
      Cls
      Incr Volume
      Locate 1 , 2
      Lcd " Volume: " ; Volume
   Else
      Locate 1 , 11
      Lcd "MAX!"
   End If
End Sub

'--------volume down--------
Sub Vol_dw :
 If Volume > 0 Then
      Cls
      Decr Volume
      Locate 1 , 2
      Lcd " Volume: " ; Volume
   Else
      Locate 1 , 11
      Lcd "MIN!"
   End If
End Sub
'--------mute----------
Sub Mute :
 Cls
      Locate 1 , 7
      Lcd "MUTE "

End Sub

'---------Poweronoff---------
Sub Poweronoff:                                             ' with pwr value it calls the proper subroutine
  Pwr = Not Pwr
   If Pwr = 1 Then
      Call Poweron
   Else
      Call Poweroff
   End If
End Sub

'-------Power on ------------
Sub Poweron:
   Display On
   Cls
   Locate 1 , 5
   Lcd "Welcome!"
   Portd.3 = 1                                              'will set the power relay on
   Waitms Timedelay
End Sub
'-------Poweroff----------------------
Sub Poweroff:
   Cls
   Locate 1 , 4
   Lcd "POWER OFF!"
   Locate 2 , 5
   Lcd "GOOD BYE"
   Waitms Timedelay
   Display Off
   Portd.3 = 0                                              'will set the power relay off
End Sub
'--------------DateTime-----------
Sub Datetime:
  CLS
  Locate 1 , 5
  Lcd Time$
  Locate 2 , 5
  Lcd Date$
  Waitms 1

End Sub
'------------Menu-----------------
Sub Menu:
  Cls
  Locate 1 , 4 : Lcd "menu"
Do

  Getrc5(address , Command)
    If Address = 0 Then
    Command = Command And &B01111111
    End If

  Select Case Command
  Case 1 : Locate 1 , 5
           Lcd "TV Input"
           Wait 2
           Call Tv
  Case 2 : Locate 1 , 3
           Lcd "CD/DVD Input"
           Wait 2
           Call Cd_dvd
  Case 3 : Call In_one
  Case 4 : Call In_two
  End Select

  If Command = 62 Then
   Exit Do
  End If

Loop
End Sub

'--------TV------------------
Sub Tv :
   Set Portd.4
   Locate 1 , 5
   Lcd "TV Input"
   Locate 2 , 5
   Lcd "Selected"
   Waitms Timedelay
   End Sub

'----------CD/DVD--------------
Sub Cd_dvd :
   Set Portd.5
   Locate 1 , 5
   Lcd "CD/DVD Input"
   Locate 2 , 5
   Lcd "Selected"
   Waitms Timedelay

End Sub

'----------input one------------
Sub In_one :
   Set Portd.6
   Locate 1 , 5
   Lcd "Input 1"
   Locate 2 , 5
   Lcd "Selected"
   Waitms Timedelay

End Sub

'----------input two----------------
Sub In_two :
   Set Portd.7
   Locate 1 , 5
   Lcd "Input 2"
   Locate 2 , 5
   Lcd "Selected"
   Waitms Timedelay

End Sub
